templatetags
==================================================
**Module**: :mod:`espressodb.base.templatetags`

.. autosummary::
    espressodb.base.templatetags.base_extras

------

.. automodule:: espressodb.base.templatetags
    :members:
    :special-members:


.. toctree::
   :glob:
   :hidden:

   *
